@@ -478,20 +478,6 @@ class UVCal(UVBase):
         self._quality_array.form = self._gain_array.form
         self._total_quality_array.form = self._gain_array.form[1:]
 
-    def set_gain(self):
-        """
-        Set cal_type to 'gain' and adjust required parameters.
-
-        This method is deprecated, and will be removed in pyuvdata v2.2. Use
-        `_set_gain` instead.
-        """
-        warnings.warn(
-            "`set_gain` is deprecated, and will be removed in pyuvdata version "
-            "2.2. Use `_set_gain` instead.",
-            DeprecationWarning,
-        )
-        self._set_gain()
-
     def _set_delay(self):
         """Set cal_type to 'delay' and adjust required parameters."""
         self.cal_type = "delay"
@@ -501,20 +487,6 @@ class UVCal(UVBase):
         self._quality_array.form = self._delay_array.form
         self._total_quality_array.form = self._delay_array.form[1:]
 
-    def set_delay(self):
-        """
-        Set cal_type to 'delay' and adjust required parameters.
-
-        This method is deprecated, and will be removed in pyuvdata v2.2. Use
-        `_set_delay` instead.
-        """
-        warnings.warn(
-            "`set_delay` is deprecated, and will be removed in pyuvdata version "
-            "2.2. Use `_set_delay` instead.",
-            DeprecationWarning,
-        )
-        self._set_delay()
-
     def _set_unknown_cal_type(self):
         """Set cal_type to 'unknown' and adjust required parameters."""
         self.cal_type = "unknown"
@@ -524,20 +496,6 @@ class UVCal(UVBase):
         self._quality_array.form = self._gain_array.form
         self._total_quality_array.form = self._gain_array.form[1:]
 
-    def set_unknown_cal_type(self):
-        """
-        Set cal_type to 'unknown' and adjust required parameters.
-
-        This method is deprecated, and will be removed in pyuvdata v2.2. Use
-        `_set_unknown_cal_type` instead.
-        """
-        warnings.warn(
-            "`set_unknown_cal_type` is deprecated, and will be removed in "
-            "pyuvdata version 2.2. Use `_set_unknown_cal_type` instead.",
-            DeprecationWarning,
-        )
-        self._set_unknown_cal_type()
-
     def _set_sky(self):
         """Set cal_style to 'sky' and adjust required parameters."""
         self.cal_style = "sky"
@@ -545,20 +503,6 @@ class UVCal(UVBase):
         self._sky_catalog.required = True
         self._ref_antenna_name.required = True
 
-    def set_sky(self):
-        """
-        Set cal_style to 'sky' and adjust required parameters.
-
-        This method is deprecated, and will be removed in pyuvdata v2.2. Use
-        `_set_sky` instead.
-        """
-        warnings.warn(
-            "`set_sky` is deprecated, and will be removed in "
-            "pyuvdata version 2.2. Use `_set_sky` instead.",
-            DeprecationWarning,
-        )
-        self._set_sky()
-
     def _set_redundant(self):
         """Set cal_style to 'redundant' and adjust required parameters."""
         self.cal_style = "redundant"
@@ -566,20 +510,6 @@ class UVCal(UVBase):
         self._sky_catalog.required = False
         self._ref_antenna_name.required = False
 
-    def set_redundant(self):
-        """
-        Set cal_style to 'redundant' and adjust required parameters.
-
-        This method is deprecated, and will be removed in pyuvdata v2.2. Use
-        `_set_redundant` instead.
-        """
-        warnings.warn(
-            "`set_redundant` is deprecated, and will be removed in "
-            "pyuvdata version 2.2. Use `_set_redundant` instead.",
-            DeprecationWarning,
-        )
-        self._set_redundant()
-
     @property
     def _data_params(self):
         """List of strings giving the data-like parameters."""
@@ -1142,6 +1072,7 @@ class UVCal(UVBase):
     def __add__(
         self,
         other,
+        verbose_history=False,
         run_check=True,
         check_extra=True,
         run_check_acceptability=True,
@@ -1154,6 +1085,14 @@ class UVCal(UVBase):
         ----------
         other : :class: UVCal
             Another UVCal object which will be added to self.
+        verbose_history : bool
+            Option to allow more verbose history. If True and if the histories for the
+            two objects are different, the combined object will keep all the history of
+            both input objects (if many objects are combined in succession this can
+            lead to very long histories). If False and if the histories for the two
+            objects are different, the combined object will have the history of the
+            first object and only the parts of the second object history that are unique
+            (this is done word by word and can result in hard to interpret histories).
         run_check : bool
             Option to check for the existence and proper shapes of parameters
             after combining objects.
@@ -1767,9 +1706,22 @@ class UVCal(UVBase):
 
         if n_axes > 0:
             history_update_string += " axis using pyuvdata."
-            this.history += history_update_string
 
-        this.history = uvutils._combine_histories(this.history, other.history)
+            histories_match = uvutils._check_histories(this.history, other.history)
+
+            this.history += history_update_string
+            if not histories_match:
+                if verbose_history:
+                    this.history += " Next object history follows. " + other.history
+                else:
+                    extra_history = uvutils._combine_history_addition(
+                        this.history, other.history
+                    )
+                    if extra_history is not None:
+                        this.history += (
+                            " Unique part of next object history follows. "
+                            + extra_history
+                        )
 
         # Check final object is self-consistent
         if run_check:
